#!/bin/bash

#author				: hennes (jm@rapidrabbit.de)
#last changed		: 07-july-2007
#status				: stable

#package			: qemulator
#homepage			: http://qemulator.createweb.de/
#source location	: http://qemulator.createweb.de/plugins/downloads/dodownload.php?file=Qemulator-0.5.tar.gz
#dependencies		: pygtk,qemu

# ----- credentials
softname="qemulator"
softversion="0.5"
srcurl="http://qemulator.createweb.de/plugins/downloads/dodownload.php?file=Qemulator-0.5.tar.gz"
arch="i486"
cpu="i686"
build="1"
zenversion="48"
packageversion="$zenversion.$build"

# ----- verify script
if [ "$(id -u)" != "0" ]; then
			echo "Please run as root!"
			exit 1
fi

# ----- help
if [ "${1}" = "--help" ]; then
	echo \
"$softname ZenBuild

usage:	--help 		Display this text
	--cleanup	Clean up after creating the package
"
	exit 0
fi

# ----- build parameters
numjobs="-j3"
builddir="$(pwd)"
package="$softname-$softversion-$arch-$packageversion"

# ----- prepare directories
dest="$builddir/$package"
rm -rf $dest
prefix="/usr"
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/doc
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p $destsrc

# ----- make slack-desc-file
cat << EOF > $dest/install/slack-desc
         |-----handy-ruler---------------------------------------------------------|
qemulator: Qemulator (a graphical emulation suite for the qemu virtual-engine)
qemulator: 
qemulator: Qemulator is a graphical emulation suite for the qemu virtual
qemulator: engine, written in python with gtk and glade.
qemulator: Finally Qemulator will try to support all engines and options for
qemulator: all common platforms. All currently not supported options can still
qemulator: be used by adding them to the available commandline.
qemulator:
qemulator:
qemulator:
qemulator:
EOF

# ----- extract source-archive
srcdir="Qemulator-"$softversion
rm -rf $srcdir
if [ -f $softname-$softversion.tar.gz ]; then
   echo "looking for source-file .. found"
else
   echo "looking for source-file .. none found"
   wget -c --output-document=$softname-$softversion.tar.gz $srcurl
fi
tar -zxvf $softname-$softversion.tar.gz
cd $srcdir

# ----- create package-dependent directories
mkdir -p $dest/usr/doc/$softname-$softversion

# ----- set target-permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;

# ----- build
cp -a usr/local/* $dest/usr

# ----- add default-files
cp -a \
	INSTALL INSTALL.DE LICENCE README TRANSLATION $dest/usr/doc/$softname-$softversion

# ----- copy build-file
cp "$builddir/build-$softname.sh" "$destsrc/build-$softname.sh"

# ----- get-source-script
cat << EOF > "$destsrc/getsrc.sh"
wget -c --output-document=$softname-$softversion.tar.gz $srcurl
EOF

chmod a+x "$destsrc/getsrc.sh"

# ----- modify desktop-file
sed -i 's|Icon=qemulator.svg|Icon=qemulator|' \
  $dest/usr/share/applications/qemulator.desktop  
  
# ----- packaging
chown -R root.root $dest/usr/bin
#chown -R root.bin $dest/$prefix/$softname
cd $dest
makepkg -l y -c n $dest.tgz
cd ..
md5sum $package.tgz > $package.md5

cat << EOF > $dest.dep
pygtk,qemu
EOF

# ----- cleaning up
if [ "${1}" = "--cleanup" ]; then
rm -r $dest
rm -r $builddir/$srcdir
fi
